@@ -255,11 +255,11 @@ class General(GUIBase):
              their own <tt>Reply-To:</tt> settings to convey their valid
              return address.  Another is that modifying <tt>Reply-To:</tt>
              makes it much more difficult to send private replies.  See <a
-             href="http://www.unicom.com/pw/reply-to-harmful.html">`Reply-To'
+             href="http://marc.merlins.org/netrants/reply-to-harmful.html">`Reply-To'
              Munging Considered Harmful</a> for a general discussion of this
              issue.  See <a
-             href="http://www.metasystema.net/essays/reply-to.mhtml">Reply-To
-             Munging Considered Useful</a> for a dissenting opinion.
+             href="http://marc.merlins.org/netrants/reply-to-useful.html">
+             Reply-To Munging Considered Useful</a> for a dissenting opinion.
 
              <p>Some mailing lists have restricted posting privileges, with a
              parallel list devoted to discussions.  Examples are `patches' or
@@ -283,11 +283,11 @@ class General(GUIBase):
              their own <tt>Reply-To:</tt> settings to convey their valid
              return address.  Another is that modifying <tt>Reply-To:</tt>
              makes it much more difficult to send private replies.  See <a
-             href="http://www.unicom.com/pw/reply-to-harmful.html">`Reply-To'
+             href="http://marc.merlins.org/netrants/reply-to-harmful.html">`Reply-To'
              Munging Considered Harmful</a> for a general discussion of this
              issue.  See <a
-             href="http://www.metasystema.net/essays/reply-to.mhtml">Reply-To
-             Munging Considered Useful</a> for a dissenting opinion.
+             href="http://marc.merlins.org/netrants/reply-to-useful.html">
+             Reply-To Munging Considered Useful</a> for a dissenting opinion.
 
              <p>Some mailing lists have restricted posting privileges, with a
              parallel list devoted to discussions.  Examples are `patches' or
